%define enable_atlas 1


%define module	numpy
%define name	python-%{module}

# disable this for bootstrapping nose and sphinx
# there is no python3-nose yet
%define enable_tests 0
%define enable_doc 0

#uncomment next line for a release candidate or a beta
#define relc rc1

#release to bump

Summary:	A fast multidimensional array facility for Python
Name:		python-%{module}
Version:	1.13.1
Release:	%mkrel 3
License:	BSD
Group:		Development/Python
Url: 		http://numpy.scipy.org
Source0:	http://download.sourceforge.net/numpy/numpy-%{version}%{?relc}.tar.xz
Provides:	f2py
Obsoletes:	f2py
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	gcc-gfortran >= 4.0
%if %enable_doc
BuildRequires:	python-sphinx >= 1.0
BuildRequires:  python-sphinx_rtd_theme
BuildRequires:	python-matplotlib
BuildRequires:	python3-sphinx >= 1.0
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:	python3-matplotlib
%endif
%if %enable_tests
BuildRequires:	python-nose
BuildRequires:	python3-nose
%endif
BuildRequires:	pkgconfig(python)
BuildRequires:	python-cython
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools

Obsoletes:	python-numeric < 24.2-8
Provides:	python-numeric

%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package devel
Summary:	Numpy headers
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Obsoletes:  python-numeric-devel
Provides:   python-numeric-devel = %version-%release

%description devel
This package contains header files need to develop modules 
in C and Fortran that can interact with Numpy

%package f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
Requires:       python-devel
Provides:       f2py = %{version}-%{release}
Obsoletes:      f2py

%description f2py
This package includes a version of f2py that works properly with NumPy.

%package -n python3-numpy
Summary:    A fast multidimensional array facility for Python3
Group:		Development/Python
License:    BSD

%description -n python3-numpy
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-numpy-devel
Summary:    Numpy headers
Group:		Development/Python
Requires:   python3-numpy
Obsoletes:  python3-numeric-devel
Provides:   python3-numeric-devel = %version-%release

%description -n python3-numpy-devel
This package contains header files need to develop modules 
in C and Fortran that can interact with Numpy

%package -n python3-numpy-f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       python3-numpy = %{version}-%{release}
Requires:       python3-devel
Provides:       python3-f2py = %{version}-%{release}
Obsoletes:      python3-f2py

%description -n python3-numpy-f2py
This package includes a version of f2py that works properly with NumPy.

%prep
%setup -q -n %{module}-%{version}%{?relc}
# workaround for rhbz#849713
# http://mail.scipy.org/pipermail/numpy-discussion/2012-July/063530.html
rm numpy/distutils/command/__init__.py && touch numpy/distutils/command/__init__.py

export CFLAGS="$CFLAGS -I /usr/include/endian.h"

cp -a . %{py3dir}

%build
pushd %{py3dir}
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py build
popd

#CFLAGS="%{optflags} -fPIC -O3" PYTHONDONTWRITEBYTECODE= %{__python2} setup.py config_fc --fcompiler=gnu95 build
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python2} setup.py build

%if %enable_doc
pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%make html
popd
%endif

%install
# first install python3 so the binaries are overwritten by the python2 ones
pushd %{py3dir}
#%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
popd &> /dev/null
popd

# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python2} setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
# symlink for anyone who was using f2py.numpy
ln -s f2py2 f2py.numpy
popd &> /dev/null
install -D -p -m 0644 doc/f2py/f2py.1 %{buildroot}%{_mandir}/man1/f2py.1

# Remove doc files that should be in %doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/COMPATIBILITY
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/*.txt
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/site.cfg.example

%check
%if %enable_tests

# Don't run tests from within main directory to avoid importing the uninstalled numpy stuff:
pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{py_platsitedir}" %{__python2} -c "import pkg_resources, numpy; numpy.test()"
popd &> /dev/null

pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{python3_sitearch}" %{__python3} -c "import pkg_resources, numpy ; numpy.test()"
popd &> /dev/null
%endif

%files
%doc THANKS.txt site.cfg.example LICENSE.txt
%if %enable_doc
%doc doc/build/html
%endif
%dir %{python2_sitearch}/%{module}
%{python2_sitearch}/%{module}/*.py*
%{python2_sitearch}/%{module}/core/ 
%{python2_sitearch}/%{module}/compat/
%{python2_sitearch}/%{module}/doc/
%exclude %{python2_sitearch}/%{module}/core/include/
%{python2_sitearch}/%{module}/fft/
%{python2_sitearch}/%{module}/lib/
%{python2_sitearch}/%{module}/linalg/
%{python2_sitearch}/%{module}/ma/
%{python2_sitearch}/%{module}/matrixlib/
%{python2_sitearch}/%{module}/polynomial/
%{python2_sitearch}/%{module}/random/
%exclude %{python2_sitearch}/%{module}/random/randomkit.h
%{python2_sitearch}/%{module}/testing/
%{python2_sitearch}/%{module}/tests/ 
%{python2_sitearch}/%{module}-*.egg-info
%{python2_sitearch}/%{module}/distutils/

%files devel
%{python2_sitearch}/%{module}/core/include/
%{python2_sitearch}/%{module}/random/randomkit.h

%files f2py
%doc doc/f2py/*.txt
%{_mandir}/man1/f2py.*
%{_bindir}/f2py2
%{_bindir}/f2py.numpy
%{python2_sitearch}/%{module}/f2py

%files -n python3-numpy
%doc THANKS.txt site.cfg.example LICENSE.txt
#%{python3_sitearch}/%{module}/__pycache__/*
%dir %{python3_sitearch}/%{module}
%{python3_sitearch}/%{module}/*.py*
%{python3_sitearch}/%{module}/core
%{python3_sitearch}/%{module}/distutils
%{python3_sitearch}/%{module}/doc/
%{python3_sitearch}/%{module}/fft
%{python3_sitearch}/%{module}/lib
%{python3_sitearch}/%{module}/linalg
%{python3_sitearch}/%{module}/ma
%{python3_sitearch}/%{module}/random
%{python3_sitearch}/%{module}/testing
%{python3_sitearch}/%{module}/tests
%{python3_sitearch}/%{module}/compat
%{python3_sitearch}/%{module}/matrixlib
%{python3_sitearch}/%{module}/polynomial
%{python3_sitearch}/%{module}-*.egg-info
%exclude %{python3_sitearch}/%{module}/core/include/
%exclude %{python3_sitearch}/%{module}/random/randomkit.h

%files -n python3-numpy-f2py
%{_bindir}/f2py3
%{python3_sitearch}/%{module}/f2py

%files -n python3-numpy-devel
%{python3_sitearch}/%{module}/core/include/
%{python3_sitearch}/%{module}/random/randomkit.h



%changelog
* Wed Jan 24 2018 adrianomorselli <adrianomorselli> 1.13-3uplos2018
- updated with new gccfortran
